function P = kzlegendre(n, m, x)
% P = kzlegendre(n, m, x) compute the associated Legendre function of
% degree n and order m. It is a wrapper function of MATLAB legendre(n,
% x) function.  Note that Matlab uses the definition of the associated
% Legendre function with Condon-Shortly phase factor.
% 
% n        an integer vector denoting the degree.
% m        an integer vector denoting the order. When m==0, we compute the
%          legendre's polynomial.  m must statisfy that m <= n.
% x        contain real values in [-1, 1] and be a column vector.
%
% n and m cannot simultaneously be vectors.

    x = reshape(x, 1, length(x));
    
    if (length(n) > 1 & length(m) > 1)
        error(['Both n and m have length greater than ONE. Only one, either ' ...
               'the order or the degree can be a vector.']);
    end
    
    if (length(n) == 1 & length(m) >= 1)
        if n > max(m)
            a = legendre(n,x);
            P = a(m+1,:);
        else
            P = zeros(length(m), length(x));
            a = legendre(n,x);
            idx = find(m<=n);
            if (~isempty(idx))
                P = a(m(idx)+1,:);
            end
        end
    else
        if m > max(m)
            P = zeros(length(n), length(x));
        else
            for i = 1:length(n)
                P(i,:) = kzlegendre(n(i), m, x);
            end
        end
    end
    
    
    